==> splidebox-1.0.1.tar.gz: splidebox/js/splidebox.load.js <==
/**
 * @file
 * Provides Splidebox loader.
 */

(function ($, Drupal, drupalSettings, _ds, _doc) {

  'use strict';

  var _id = 'splidebox';
  var _idOnce = _id;
  var _mounted = 'is-' + _id + '--mounted';
  var _dataId = 'data-' + _id;
  var _gallery = '[' + _dataId + '-gallery]';
  var _trigger = '[' + _dataId + '-trigger]';
  var splidebox = drupalSettings.splidebox || {};
  var boxSettings = splidebox.lightbox || {};
  var splideSettings = splidebox.splide || {};

  /**
   * Splidebox utility functions.
   *
   * @param {HTMLElement} elm
   *   The Splidebox gallery HTML element.
   */
  function process(elm) {

    // Initializes splide.
    function init(el, options) {
      var splide;
      Drupal.detachBehaviors(el);

      _ds.options = $.extend({}, _ds.options, options || {});
      splide = _ds.init(el);

      window.setTimeout(function () {
        Drupal.attachBehaviors(el);
      });
      return splide;
    }

    var options = {
      template: splidebox.template || '',
      trigger: _trigger,
      dataSplide: splideSettings,
      fsIconOn: _ds.fsIconOn,
      init: init
    };

    // Build Splidebox gallery.
    options = $.extend({}, boxSettings, options);
    Splidebox.init(elm, options);

    $.addClass(elm, _mounted);
  }

  /**
   * Attaches Splidebox gallery behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.splidebox = {
    attach: function (context) {

      context = $.context(context);

      $.once(process, _idOnce, _gallery, context);
    },
    detach: function (context, setting, trigger) {
      if (trigger === 'unload') {
        $.once.removeSafely(_idOnce, _gallery, context);
      }
    }
  };

})(dBlazy, Drupal, drupalSettings, dSplide, this.document);

==> splidebox-1.0.2-rc3.tar.gz: splidebox/js/splidebox.load.js <==
/**
 * @file
 * Provides Splidebox loader.
 */

(function ($, Drupal, drupalSettings, _ds, _win, _doc) {

  'use strict';

  var _id = 'splidebox';
  var _idOnce = _id;
  var _mounted = 'is-' + _id + '-mounted';
  var _dataId = 'data-' + _id;
  var _gallery = '[' + _dataId + '-gallery]:not(.' + _mounted + ')';
  var _trigger = '[' + _dataId + '-trigger]';
  var splidebox = drupalSettings.splidebox || {};
  var boxSettings = splidebox.lightbox || {};
  var splideSettings = splidebox.splide || {};

  /**
   * Splidebox utility functions.
   *
   * @param {HTMLElement} elm
   *   The Splidebox gallery HTML element.
   */
  function process(elm) {

    // Initializes splide.
    function init(el, options) {
      var splide;
      Drupal.detachBehaviors(el);

      _ds.options = $.extend({}, _ds.options, options || {});
      splide = _ds.init(el);

      _win.setTimeout(function () {
        Drupal.attachBehaviors(el);
      });
      return splide;
    }

    var dataAttr = $.attr(elm, 'data-splidebox');
    if (dataAttr) {
      splideSettings = $.extend({}, splideSettings, $.parse(dataAttr));
    }

    var options = {
      template: splidebox.template || '',
      trigger: _trigger,
      dataSplide: splideSettings,
      fsIconOn: _ds.fsIconOn,
      init: init
    };

    // Build Splidebox gallery.
    options = $.extend({}, boxSettings, options);
    _win.setTimeout(function () {
      Splidebox.init(elm, options);
    });

    $.addClass(elm, _mounted);
  }

  /**
   * Attaches Splidebox gallery behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.splidebox = {
    attach: function (context) {
      $.once(process, _idOnce, _gallery, context);
    },
    detach: function (context, setting, trigger) {
      if (trigger === 'unload') {
        $.once.removeSafely(_idOnce, _gallery, context);
      }
    }
  };

})(dBlazy, Drupal, drupalSettings, dSplide, this, this.document);
